==> viha-5.15.tar.gz: viha-5.15/ryhma_tila0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma_tila";
$file = basename(__FILE__);

include "common.php";
include "ryhma_tila-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmn tilakoodit</title>
</head>
" . body_bgcolor() . "
<h1>Ryhmn tilakoodien ksittely ja siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$ryhma_tila = get_txt('ryhma_tila');
$suojattu = get_txt('suojattu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_tila_add_ok($herja,$alue_id,$paivystys_id,$ryhma_tila);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           ryhma_tila = '$ryhma_tila',
           suojattu = 0,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_tila_save_ok($herja,$id,$alue_id,$paivystys_id,$ryhma_tila);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           paivystys_id=$paivystys_id,
           ryhma_tila='$ryhma_tila',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_tila_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 }
if ($clear != '') {
  $id = "0";
  $alue_id = 1;
  $paivystys_id = 1;
  $ryhma_tila = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_tila_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $ryhma_tila = $a['ryhma_tila'];
  $suojattu = $a['suojattu'];
  if ($suojattu == 1) { $readonly = 1; }
 }		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Tilakoodi:";
if ($readonly) {
  echo "<td>$ryhma_tila\n";
} else {
  echo "<td><input type=\"text\" name=\"ryhma_tila\" size=64 maxlength=64";
  echo " value=\"$ryhma_tila\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,alue.alue,paivystys.nimi,
                         ryhma_tila,suojattu,$table.ts,
                         $table.alue_id,$table.paivystys_id
                  FROM $table,alue,paivystys
                  WHERE $table.alue_id = alue.id
                        AND $table.paivystys_id = paivystys.id
                  ORDER BY alue_id,paivystys_id,ryhma_tila");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
  . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Operaatio<TH>Tilakoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[nimi]",
      "<TD>$a[ryhma_tila]";
    if (($id == "0") && ($a['id'] != "1")) {
      if ($a['suojattu'] == 0) {
	echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei ryhmn tilakoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma_tila0.php,v 1.17 2009/06/12 10:08:23 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/ryhma_tila0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma_tila";
$file = basename(__FILE__);

include "common.php";
include "ryhma_tila-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmn tilakoodit</title>
</head>
" . body_bgcolor() . "
<h1>Ryhmn tilakoodien ksittely ja siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$ryhma_tila = get_txt('ryhma_tila');
$suojattu = get_txt('suojattu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_tila_add_ok($herja,$alue_id,$paivystys_id,$ryhma_tila);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = $alue_id,
           paivystys_id = $paivystys_id,
           ryhma_tila = '$ryhma_tila',
           suojattu = 0,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_tila_save_ok($herja,$id,$alue_id,$paivystys_id,$ryhma_tila);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = $alue_id,
           paivystys_id=$paivystys_id,
           ryhma_tila='$ryhma_tila',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_tila_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 }
if ($clear != '') {
  $id = "0";
  $alue_id = 1;
  $paivystys_id = 1;
  $ryhma_tila = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_tila_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $ryhma_tila = $a['ryhma_tila'];
  $suojattu = $a['suojattu'];
  if ($suojattu == 1) { $readonly = 1; }
 }		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  select_alue($alue_id);
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  select_paivystys($paivystys_id);
}

echo "<tr><td>Tilakoodi:";
if ($readonly) {
  echo "<td>$ryhma_tila\n";
} else {
  echo "<td><input type=\"text\" name=\"ryhma_tila\" size=64 maxlength=64";
  echo " value=\"$ryhma_tila\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result =
  my_mysql_query("SELECT $table.id,alue.alue,paivystys.nimi,
                         ryhma_tila,suojattu,$table.ts,
                         $table.alue_id,$table.paivystys_id
                  FROM $table,alue,paivystys
                  WHERE $table.alue_id = alue.id
                        AND $table.paivystys_id = paivystys.id
                  ORDER BY alue_id,paivystys_id,ryhma_tila");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
  . "<TH>Id<TH>Aikaleima<TH>Alue<TH>Operaatio<TH>Tilakoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[alue]",
      "<TD>$a[nimi]",
      "<TD>$a[ryhma_tila]";
    if (($id == "0") && ($a['id'] != "1")) {
      if ($a['suojattu'] == 0) {
	echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei ryhmn tilakoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma_tila0.php,v 1.21 2009/09/29 16:09:15 riku Exp $ -->
